==> alfred-ui-native-components-0.0.158.tgz: package/ui/molecules/textButtonInputs/block/large/default/index.tsx <==
import React, { FC, useState } from 'react';
import { TextInput, Text, View } from 'react-native';
import { PrimarySmallTextFlatButton } from '../../../../../atoms';
import { autoCapitalizeTypesEnum, keyboardTypesEnum, TextInputModels } from '../../../../../atoms/textInput/textInputModels';
import { styles } from '../../../../../atoms/textInput/block/styles';

export const TextButtonInputLarge: FC<TextInputModels> = ({
  keyboardType= keyboardTypesEnum.DEFAULT,
  autoCapitalize = autoCapitalizeTypesEnum.NONE,
  isSecureTextEntry= false,
  isError= false,
  isDisabled= false,
  isAutoFocus= false,
  maxLength= 255,
  onChangeText,
  onClickButton,
  errorText,
  defaultValue,
  placeholder,
  buttonText,
}) => {
  const [isFocused, setIsFocused] = useState(false);
  const [maxLengthCompleted, setMaxLengthCompleted] = useState(false);

  const handleChangeText = (val: string) => {
    val.length === maxLength ? setMaxLengthCompleted(true) : setMaxLengthCompleted(false);
    onChangeText?.(val);
  };

  return (
    <View style={styles.textInputContainer}>
      <TextInput
        secureTextEntry={isSecureTextEntry}
        autoFocus={isAutoFocus}
        defaultValue={defaultValue}
        editable={!isDisabled}
        maxLength={maxLength}
        autoCapitalize={autoCapitalize}
        placeholderTextColor={
          isDisabled
            ? styles.textInputDisabled.placeholderText.color
            : styles.textInput.placeholderText.color
        }
        placeholder={placeholder}
        onChangeText={handleChangeText}
        onFocus={() => setIsFocused(true)}
        onEndEditing={() => setIsFocused(false)}
        keyboardType={keyboardType}
        style={[
          styles.textInput,
          styles.textButtonInput,
          styles.textInputLarge,
          isFocused && styles.textInputActive,
          isDisabled && styles.textInputDisabled,
          isError && styles.textInputError,
          maxLengthCompleted && styles.textInputError,
        ]}
      />
      {isError && <Text numberOfLines={1} style={styles.textInputErrorText}>{errorText}</Text>}
      <View style={[styles.button, styles.largeSizeButton]} >
        <PrimarySmallTextFlatButton
          onClick={onClickButton}
          disabled={isDisabled}
          text={buttonText}
        />
      </View>
    </View>
  );
};

==> alfred-ui-native-components-0.0.166.tgz: package/ui/molecules/textButtonInputs/block/large/default/index.tsx <==
import React, { FC, useState } from 'react';
import { TextInput, Text, View } from 'react-native';
import { PrimarySmallTextFlatButton } from '../../../../../atoms';
import { autoCapitalizeTypesEnum, keyboardTypesEnum, TextInputModels } from '../../../../../atoms/textInput/textInputModels';
import { styles } from '../../../../../atoms/textInput/block/styles';

export const TextButtonInputLarge: FC<TextInputModels> = ({
  keyboardType= keyboardTypesEnum.DEFAULT,
  autoCapitalize = autoCapitalizeTypesEnum.NONE,
  isSecureTextEntry= false,
  isError= false,
  isDisabled= false,
  isAutoFocus= false,
  maxLength= 255,
  onChangeText,
  onClickButton,
  errorText,
  defaultValue,
  placeholder,
  buttonText,
}) => {
  const [isFocused, setIsFocused] = useState(false);
  const [maxLengthCompleted, setMaxLengthCompleted] = useState(false);

  const handleChangeText = (val: string) => {
    val.length === maxLength ? setMaxLengthCompleted(true) : setMaxLengthCompleted(false);
    onChangeText?.(val);
  };

  return (
    <View style={styles().textInputContainer}>
      <TextInput
        secureTextEntry={isSecureTextEntry}
        autoFocus={isAutoFocus}
        defaultValue={defaultValue}
        editable={!isDisabled}
        maxLength={maxLength}
        autoCapitalize={autoCapitalize}
        placeholderTextColor={
          isDisabled
            ? styles().textInputDisabled.placeholderText.color
            : styles().textInput.placeholderText.color
        }
        placeholder={placeholder}
        onChangeText={handleChangeText}
        onFocus={() => setIsFocused(true)}
        onEndEditing={() => setIsFocused(false)}
        keyboardType={keyboardType}
        style={[
          styles().textInput,
          styles().textButtonInput,
          styles().textInputLarge,
          isFocused && styles().textInputActive,
          isDisabled && styles().textInputDisabled,
          isError && styles().textInputError,
          maxLengthCompleted && styles().textInputError,
        ]}
      />
      {isError && <Text numberOfLines={1} style={styles().textInputErrorText}>{errorText}</Text>}
      <View style={[styles().button, styles().largeSizeButton]} >
        <PrimarySmallTextFlatButton
          onClick={onClickButton}
          disabled={isDisabled}
          text={buttonText}
        />
      </View>
    </View>
  );
};
